@@ -1,8 +1,16 @@
 #pragma once
 
-#include <nlohmann/json.hpp>
+/// @file
+/// @brief Alias events.
 
-using json = nlohmann::json;
+#include <string>
+#include <vector>
+
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
+#include <nlohmann/json.hpp>
+#endif
 
 namespace mtx {
 namespace events {
@@ -17,17 +25,17 @@ namespace state {
 //! the `m.room.aliases` events, one for each homeserver.
 struct Aliases
 {
-        //! A list of room aliases.
-        std::vector<std::string> aliases;
+    //! A list of room aliases.
+    std::vector<std::string> aliases;
 };
 
 //! Deserialization method needed by @p nlohmann::json.
 void
-from_json(const json &obj, Aliases &content);
+from_json(const nlohmann::json &obj, Aliases &content);
 
 //! Serialization method needed by @p nlohmann::json.
 void
-to_json(json &obj, const Aliases &content);
+to_json(nlohmann::json &obj, const Aliases &content);
 
 } // namespace state
 } // namespace events
