@@ -1,8 +1,13 @@
 #pragma once
 
-#include <nlohmann/json.hpp>
+/// @file
+/// @brief Room avatar events.
 
-using json = nlohmann::json;
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
+#include <nlohmann/json.hpp>
+#endif
 
 #include "mtx/events/common.hpp"
 
@@ -16,19 +21,19 @@ namespace state {
 //! This can be displayed alongside the room information.
 struct Avatar
 {
-        //! Metadata about the image referred to in @p url.
-        mtx::common::ImageInfo image_info;
-        //! The URL to the image.
-        std::string url;
+    //! Metadata about the image referred to in @p url.
+    mtx::common::ImageInfo image_info;
+    //! The URL to the image.
+    std::string url;
 };
 
 //! Deserialization method needed by @p nlohmann::json.
 void
-from_json(const json &obj, Avatar &avatar);
+from_json(const nlohmann::json &obj, Avatar &avatar);
 
 //! Serialization method needed by @p nlohmann::json.
 void
-to_json(json &obj, const Avatar &avatar);
+to_json(nlohmann::json &obj, const Avatar &avatar);
 
 } // namespace state
 } // namespace events
