@@ -1,8 +1,15 @@
 #pragma once
 
-#include <nlohmann/json.hpp>
+/// @file
+/// @brief Change the canonical or listed avatars of a room.
 
-using json = nlohmann::json;
+#include <string>
+
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
+#include <nlohmann/json.hpp>
+#endif
 
 namespace mtx {
 namespace events {
@@ -16,17 +23,20 @@ namespace state {
 //! use to advertise the room.
 struct CanonicalAlias
 {
-        //! The canonical alias. Could be *null*.
-        std::string alias;
+    //! The canonical alias. Could be *null*.
+    std::string alias;
+    //! Alternative aliases the room advertises. This list can have aliases despite the alias
+    //! field being null, empty, or otherwise not present.
+    std::vector<std::string> alt_aliases;
 };
 
 //! Deserialization method needed by @p nlohmann::json.
 void
-from_json(const json &obj, CanonicalAlias &canonical_alias);
+from_json(const nlohmann::json &obj, CanonicalAlias &canonical_alias);
 
 //! Serialization method needed by @p nlohmann::json.
 void
-to_json(json &obj, const CanonicalAlias &canonical_alias);
+to_json(nlohmann::json &obj, const CanonicalAlias &canonical_alias);
 
 } // namespace state
 } // namespace events
