@@ -1,5 +1,8 @@
 #pragma once
 
+/// @file
+/// @brief Events describing an emotion or action.
+
 #if __has_include(<nlohmann/json_fwd.hpp>)
 #include <nlohmann/json_fwd.hpp>
 #else
@@ -14,18 +17,19 @@ namespace mtx {
 namespace events {
 namespace msg {
 
+//! Content of `m.room.message` with msgtype `m.emote`.
 struct Emote
 {
-        // The emote action to perform.
-        std::string body;
-        // Must be 'm.emote'.
-        std::string msgtype;
-        //! We only handle org.matrix.custom.html.
-        std::string format;
-        //! HTML formatted message.
-        std::string formatted_body;
-        //! Relates to for rich replies
-        mtx::common::RelatesTo relates_to;
+    // The emote action to perform.
+    std::string body;
+    // Must be 'm.emote'.
+    std::string msgtype;
+    //! We only handle org.matrix.custom.html.
+    std::string format;
+    //! HTML formatted message.
+    std::string formatted_body;
+    //! Relates to for rich replies
+    mtx::common::Relations relations;
 };
 
 void
