@@ -1,17 +1,24 @@
 #pragma once
 
+/// @file
+/// @brief Collection header for all the different response structs.
+
 #include "responses/common.hpp"
 
 #include "responses/create_room.hpp"
 #include "responses/crypto.hpp"
+#include "responses/device.hpp"
 #include "responses/empty.hpp"
 #include "responses/groups.hpp"
 #include "responses/login.hpp"
 #include "responses/media.hpp"
+#include "responses/members.hpp"
 #include "responses/messages.hpp"
 #include "responses/notifications.hpp"
 #include "responses/profile.hpp"
+#include "responses/public_rooms.hpp"
 #include "responses/register.hpp"
 #include "responses/sync.hpp"
+#include "responses/turn_server.hpp"
 #include "responses/version.hpp"
 #include "responses/well-known.hpp"
