@@ -1,8 +1,13 @@
 #pragma once
 
-#include <string>
+/// @file
+/// @brief Empty responses returned by different endpoints.
 
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
 #include <nlohmann/json.hpp>
+#endif
 
 #include "mtx/identifiers.hpp"
 
