@@ -1,8 +1,15 @@
 #pragma once
 
+/// @file
+/// @brief Reponses from the message pagination API.
+
 #include <string>
 
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
 #include <nlohmann/json.hpp>
+#endif
 
 #include "mtx/events/collections.hpp"
 
@@ -15,12 +22,12 @@ namespace responses {
 //! It uses pagination query parameters to paginate history in the room.
 struct Messages
 {
-        //! The token the pagination starts from.
-        std::string start;
-        //! The token the pagination ends at.
-        std::string end;
-        //! A list of room events.
-        std::vector<mtx::events::collections::TimelineEvents> chunk;
+    //! The token the pagination starts from.
+    std::string start;
+    //! The token the pagination ends at.
+    std::string end;
+    //! A list of room events.
+    std::vector<mtx::events::collections::TimelineEvents> chunk;
 };
 
 void
