@@ -1,6 +1,13 @@
 #pragma once
 
+/// @file
+/// @brief Return value of the server and API version query.
+
+#if __has_include(<nlohmann/json_fwd.hpp>)
+#include <nlohmann/json_fwd.hpp>
+#else
 #include <nlohmann/json.hpp>
+#endif
 
 namespace mtx {
 namespace responses {
@@ -10,8 +17,8 @@ namespace responses {
 //! Gets the versions of the specification supported by the server.
 struct Versions
 {
-        //! The supported versions.
-        std::vector<std::string> versions;
+    //! The supported versions.
+    std::vector<std::string> versions;
 };
 
 void
