@@ -1,13 +1,11 @@
 #include "mtx/responses/empty.hpp"
 
-using json = nlohmann::json;
-
 namespace mtx {
 namespace responses {
 
 // Provides a deserialization function to use when empty responses are returned from the server
 void
-from_json(const json &, Empty &)
+from_json(const nlohmann::json &, Empty &)
 {}
 }
 }
